@@ -18,7 +18,7 @@ struct procstat* get_procstat( char* path, struct procstat* prs)
 		return NULL;
 
 	result = fscanf(fp, 
-			"%d %s %c %d %d %d %d %d %u %u %u %u %u %Ld %Ld %Ld %Ld %d %d %u %u %lu %u %u %u %u %u %u %u %u %d %d %d %d %u",
+			"%d %s %c %d %d %d %d %d %u %u %u %u %u %Ld %Ld %Ld %Ld %d %d %u %u %lu %lu %lu %u %u %u %u %u %u %d %d %d %d %u",
 			&prs->pid, 
 			prs->comm,		/* char comm[FILENAME_MAX]; */
 			&prs->state, 
